summaryrefslogtreecommitdiff
path: root/pjnath/include
diff options
context:
space:
mode:
authorBenny Prijono <bennylp@teluu.com>2008-03-08 00:54:04 +0000
committerBenny Prijono <bennylp@teluu.com>2008-03-08 00:54:04 +0000
commite30de41312b8f3552dea56db5eb73d99889f6941 (patch)
tree94af9773e03bffd53f58620a87c26da737db62df /pjnath/include
parent2eeebb98f8e4fc3f84fe8d16548035b605ff0929 (diff)
More work on ticket #485: more TURN-07 work
git-svn-id: http://svn.pjsip.org/repos/pjproject/trunk@1850 74dad513-b988-da41-8d7b-12977e46ad98
Diffstat (limited to 'pjnath/include')
-rw-r--r--pjnath/include/pjnath/stun_msg.h52
1 files changed, 49 insertions, 3 deletions
diff --git a/pjnath/include/pjnath/stun_msg.h b/pjnath/include/pjnath/stun_msg.h
index 933c5e9f..8946a71b 100644
--- a/pjnath/include/pjnath/stun_msg.h
+++ b/pjnath/include/pjnath/stun_msg.h
@@ -67,11 +67,26 @@ enum pj_stun_method_e
PJ_STUN_ALLOCATE_METHOD = 3,
/**
* STUN/TURN Send Indication as defined by draft-ietf-behave-turn
*/
PJ_STUN_REFRESH_METHOD = 4,
/**
+ * STUN/TURN Send indication as defined by draft-ietf-behave-turn
+ */
+ PJ_STUN_SEND_METHOD = 6,
+
+ /**
+ * STUN/TURN Data indication as defined by draft-ietf-behave-turn
+ */
+ PJ_STUN_DATA_METHOD = 7,
+
+ /**
+ * STUN/TURN ChannelBind as defined by draft-ietf-behave-turn
+ */
+ PJ_STUN_CHANNEL_BIND_METHOD = 9,
+
+ /**
* All known methods.
*/
PJ_STUN_METHOD_MAX
@@ -176,6 +191,7 @@ typedef enum pj_stun_msg_type
*/
PJ_STUN_BINDING_ERROR_RESPONSE = 0x0111,
+
/**
* STUN SHARED-SECRET reqeust.
*/
@@ -191,6 +207,7 @@ typedef enum pj_stun_msg_type
*/
PJ_STUN_SHARED_SECRET_ERROR_RESPONSE = 0x0112,
+
/**
* STUN/TURN Allocate Request
*/
@@ -206,6 +223,7 @@ typedef enum pj_stun_msg_type
*/
PJ_STUN_ALLOCATE_ERROR_RESPONSE = 0x0113,
+
/**
* STUN/TURN REFRESH Request
*/
@@ -219,7 +237,35 @@ typedef enum pj_stun_msg_type
/**
* Error response to STUN REFRESH request.
*/
- PJ_STUN_REFRESH_ERROR_RESPONSE = 0x0114
+ PJ_STUN_REFRESH_ERROR_RESPONSE = 0x0114,
+
+
+ /**
+ * TURN Send indication
+ */
+ PJ_STUN_SEND_INDICATION = 0x0016,
+
+
+ /**
+ * TURN Data indication
+ */
+ PJ_STUN_DATA_INDICATION = 0x0017,
+
+
+ /**
+ * STUN/TURN ChannelBind Request
+ */
+ PJ_STUN_CHANNEL_BIND_REQUEST = 0x0009,
+
+ /**
+ * Successful response to STUN ChannelBind request
+ */
+ PJ_STUN_CHANNEL_BIND_RESPONSE = 0x0109,
+
+ /**
+ * Error response to STUN ChannelBind request.
+ */
+ PJ_STUN_CHANNEL_BIND_ERROR_RESPONSE = 0x0119
} pj_stun_msg_type;
@@ -947,7 +993,7 @@ typedef struct pj_stun_uint_attr pj_stun_req_port_props_attr;
* Get the port number in TURN REQUESTED-PORT-PROPS attribute. The port
* number is returned in host byte order.
*/
-#define PJ_STUN_GET_RPP_PORT(u32) pj_ntons((pj_uint16_t)(u32 & 0x0000FFFFL))
+#define PJ_STUN_GET_RPP_PORT(u32) pj_ntohs((pj_uint16_t)(u32 & 0x0000FFFFL))
/**
* Convert port number in host byte order to 32bit value to be encoded in
@@ -67,11 +67,26 @@ enum pj_stun_method_e
PJ_STUN_ALLOCATE_METHOD = 3,
/**
- * STUN/TURN Send Indication as defined by draft-ietf-behave-turn
+ * STUN/TURN Refresh method as defined by draft-ietf-behave-turn
*/
PJ_STUN_REFRESH_METHOD = 4,